package de.cnam.jemina.ui.components;

import com.vaadin.event.ShortcutAction;
import com.vaadin.event.ShortcutListener;
import com.vaadin.ui.Button;
import com.vaadin.ui.Button.ClickEvent;
import com.vaadin.ui.Component;
import com.vaadin.ui.CustomComponent;
import com.vaadin.ui.HorizontalLayout;
import com.vaadin.ui.TextField;
import de.cnam.jemina.i18n.LocalizationManager;
import java.io.Serializable;

/**
 * Suchefeld 
 * @author CNAM Team (Nadine, Mike, Jens)
 * @since 19.01.2013
 */
public class SearchComponent extends CustomComponent {
    
    // Fuer die Uebersetzung:
    private final LocalizationManager locale = LocalizationManager.getLocalizationManager(SearchComponent.class);
    
    // UI Komponenten:
    private HorizontalLayout layout;
    private TextField sucheingabe;
    private SearchButton suchKnopf;
    
    private SuchListener suchAktion;

    public SearchComponent() {
        super();
        setCompositionRoot(genContent());
    }
    
    /**
     * Erstellt die UI
     * @return 
     */
    private Component genContent() {
        layout = new HorizontalLayout();
        layout.setWidth(500F, UNITS_PIXELS);
        
        // Textfeld:
        sucheingabe = new TextField();
        sucheingabe.setInputPrompt(locale.localize("sucheprompt"));
        sucheingabe.setWidth(100F, UNITS_PERCENTAGE);
        sucheingabe.setImmediate(true);
        
        // Knopf:
        suchKnopf = new SearchButton();
        suchKnopf.addShortcutListener(new ShortcutListener("enterListener", ShortcutAction.KeyCode.ENTER, null) {
            @Override
            public void handleAction(Object sender, Object target) {
                if (target == sucheingabe) {
//                    suchKnopf.removeShortcutListener(this);
                    suchAktion.suche(sucheingabe.getValue().toString());
                }
            }
        });
        
        // Layout:
        layout.addComponent(sucheingabe);
        layout.setExpandRatio(sucheingabe, 100F);
        layout.addComponent(suchKnopf);
                
        // Wenn der Anwender auf den Suchen-Knopf drueckt:
        suchKnopf.addListener(new Button.ClickListener() {
            @Override
            public void buttonClick(ClickEvent event) {
                if (suchAktion != null) {
                    suchAktion.suche(sucheingabe.getValue().toString());
                }
            }
        });
                
        return layout;
    }
    
    /**
     * Setzt den Text, der angezeigt wird wenn das Textfeld leer ist.
     * @param txt Text der angezeigt werden soll
     * @see TextField#setInputPrompt(java.lang.String) 
     */
    public void setInputPrompt(String txt) {
        sucheingabe.setInputPrompt(txt);
    }
    
    /**
     * Setzt den Text f&uuml;r die Sucheschaltfl&auml;che
     * @param txt Text der angezeigt werden soll
     */
    public void setButtonCaption(String txt) {
        suchKnopf.setCaption(txt);
    }
    
    /**
     * <p>Liefert den aktuellen Inhalt der Sucheingabe.</p>
     * <p>Bitte einen {@link #setSuchListener(de.cnam.jemina.ui.components.SearchComponent.SuchListener) Listener}
     * verwenden, um den zu suchenden Begriff zu erhalten.</p>
     * @return 
     */
    public Object getValue() {
        return sucheingabe.getValue();
    }
    
    /**
     * Belegt die Sucheingabe mit einem Wert vor.
     * @param value 
     */
    public void setValue(Object value) {
        sucheingabe.setValue(value);
    }

    @Override
    public void setWidth(float width, int unit) {
        if (layout != null) {
            layout.setWidth(width, unit);
        }
    }
    
    @Override
    public void focus() {
        sucheingabe.focus();
    }
    
    /**
     * Setzt den Listener, der informiert wird, wenn der Anwender eine
     * Suche gestartet hat
     * @param listener 
     */
    public void setSuchListener(SuchListener listener) {
        suchAktion = listener;
    }
    
    /**
     * Dieser Listener wird aufgerufen, wenn der Anwender eine Suche startet
     */
    public static interface SuchListener extends Serializable {
        
        /**
         * Diese Methode wird aufgerufen, wenn der Anwender eine Suche
         * gestartet hat.
         * @param suchbegriff Die Eingabe des Anwenders
         */
        public void suche(String suchbegriff);
    }
}
