package de.cnam.jemina.ui.views.impl;

import com.vaadin.data.Container;
import com.vaadin.data.util.BeanItem;
import com.vaadin.ui.Component;
import com.vaadin.ui.CustomComponent;
import com.vaadin.ui.Table;
import com.vaadin.ui.VerticalLayout;
import de.cnam.jemina.i18n.LocalizationManager;
import de.cnam.jemina.objects.Reservierung;
import de.cnam.jemina.ui.views.utils.ViewUtils;

/**
 *
 * @author CNAM Team (Nadine, Mike, Jens)
 */
public class ListMyItemsView extends CustomComponent {

    // Fuer die Uebersetzung:
    private final LocalizationManager locale = LocalizationManager.getLocalizationManager(ListMyItemsView.class);

    // UI
    private Table table;


    public ListMyItemsView() {
        super();
        setSizeFull();
        setCompositionRoot(buildContent());
    }
    
    private Component buildContent() {
        VerticalLayout layout = new VerticalLayout();
        layout.setSpacing(true);
        layout.setMargin(true);
        layout.setSizeFull();
                
        table = new Table(locale.localize("myreserve"));
        table.setSizeFull();
        layout.addComponent(table);
        layout.setExpandRatio(table, 100F);
        
        return layout;
    }
    
    /**
     * Setzt die Daten, die angezeigt werden sollen
     * @param container 
     */
    public void setContainer(Container container) {
        try {
            table.setContainerDataSource(container);
            table.setVisibleColumns(new Object[] { "nummer", "artikel", "filiale" } );

            // Darstellung von Artikel
            table.addGeneratedColumn("artikel", new Table.ColumnGenerator() {
                @Override
                public Object generateCell(Table source, Object itemId, Object columnId) {
                    Reservierung r = (Reservierung) ((BeanItem)source.getItem(itemId)).getBean();
                    return r.getArtikel().getTitel();
                }
            });

            // Darstellung von Filiale
            table.addGeneratedColumn("filiale", new Table.ColumnGenerator() {
                @Override
                public Object generateCell(Table source, Object itemId, Object columnId) {
                    Reservierung r = (Reservierung) ((BeanItem)source.getItem(itemId)).getBean();
                    return r.getFiliale().getName();
                }
            });

            // Spaltenueberschriften:
            ViewUtils.translateTableHeader(table, locale);
        } catch (Exception ex) {
            // Fehler kommt bei keinen Daten
            
        }
    }

}
